@@ -32,8 +32,8 @@ from time import sleep
 
 import numpy as np
 import gdal
-from py_tools_ds.geo.projection import EPSG2WKT, WKT2EPSG, proj4_to_WKT, proj4_to_dict
-from py_tools_ds.geo.coord_trafo import get_proj4info, transform_coordArray, transform_any_prj
+from pyproj import CRS
+from py_tools_ds.geo.coord_trafo import transform_coordArray, transform_any_prj
 from py_tools_ds.geo.coord_calc import corner_coord_to_minmax, get_corner_coordinates
 from py_tools_ds.geo.coord_grid import find_nearest
 from py_tools_ds.io.raster.writer import write_numpy_to_image
@@ -100,9 +100,8 @@ class SensorMapGeometryTransformer(object):
 
         # NOTE: If pykdtree is built with OpenMP support (default) the number of threads is controlled with the
         #       standard OpenMP environment variable OMP_NUM_THREADS. The nprocs argument has no effect on pykdtree.
+        os.environ['OMP_NUM_THREADS'] = '%d' % (self.opts['nprocs'] if 'nprocs' in self.opts else 1)
         if 'nprocs' in self.opts:
-            if self.opts['nprocs'] > 1:
-                os.environ['OMP_NUM_THREADS'] = '%d' % opts['nprocs']
             del self.opts['nprocs']
 
         self.lats = lats
@@ -145,7 +144,7 @@ class SensorMapGeometryTransformer(object):
         """
         # get the target extent if not given
         # (this also makes sure that create_area_def does not return a DynamicAreaDefinition)
-        tgt_epsg = WKT2EPSG(proj4_to_WKT(get_proj4info(proj=tgt_prj)))
+        tgt_epsg = CRS(tgt_prj).to_epsg()
         tgt_extent = tgt_extent or self._get_target_extent(tgt_epsg)
 
         if tgt_res:
@@ -159,15 +158,15 @@ class SensorMapGeometryTransformer(object):
             #          passing LonLats and resolution
             area_definition = \
                 create_area_def(area_id='',
-                                projection=get_proj4info(proj=tgt_prj),
+                                projection='EPSG:%d' % CRS(tgt_prj).to_epsg(),
                                 area_extent=tgt_extent,
                                 resolution=tgt_res)
 
             out_res = (area_definition.pixel_size_x, area_definition.pixel_size_y)
             if tgt_res and tgt_res != out_res:
-                warnings.warn('With respect to the Lon/Lat arrays the pixel size was set to %s instead of the desired '
-                              '%s. Provide a target extent where the coordinates are multiples of the pixel sizes to '
-                              'avoid this.' % (str(out_res), str(tgt_res)), UserWarning)
+                warnings.warn(f'With respect to the Lon/Lat arrays the pixel size was set to {str(out_res)} instead of '
+                              f'the desired {str(tgt_res)}. Provide a target extent where the coordinates are '
+                              f'multiples of the pixel sizes to avoid this.', UserWarning)
 
         else:
             def raiseErr_if_empty(gdal_ds):
@@ -189,7 +188,7 @@ class SensorMapGeometryTransformer(object):
                     # xy_coords = np.dstack([self.swath_definition.lons[::10, ::10],
                     #                        self.swath_definition.lats[::10, ::10]])
                 else:
-                    xy_coords = np.dstack(list(transform_coordArray(EPSG2WKT(4326), EPSG2WKT(tgt_epsg),
+                    xy_coords = np.dstack(list(transform_coordArray(CRS(4326).to_wkt(), CRS(tgt_epsg).to_wkt(),
                                                                     self.swath_definition.lons,
                                                                     self.swath_definition.lats)))
                 write_numpy_to_image(xy_coords, path_xycoords, 'ENVI')
@@ -214,24 +213,22 @@ class SensorMapGeometryTransformer(object):
                                  "LINE_OFFSET": "0",
                                  "PIXEL_STEP": "1",
                                  "LINE_STEP": "1",
-                                 "SRS": EPSG2WKT(tgt_epsg),
+                                 "SRS": CRS(tgt_epsg).to_wkt(),
                                  }, "GEOLOCATION")
                 vrt.FlushCache()
                 del ds_data, vrt
 
-                subcall_with_output("gdalwarp '%s' '%s' "
-                                    '-geoloc '
-                                    '-t_srs EPSG:%d '
-                                    '-srcnodata 0 '
-                                    '-r near '
-                                    '-of ENVI '
-                                    '-dstnodata none '
-                                    '-et 0 '
-                                    '-overwrite '
-                                    '-te %s '
-                                    '%s' % (path_datavrt, path_data_out, tgt_epsg,
-                                            ' '.join([str(i) for i in tgt_extent]),
-                                            ' -tr %s %s' % tgt_res if tgt_res else '',),
+                subcall_with_output(f"gdalwarp '{path_datavrt}' '{path_data_out}' "
+                                    f'-geoloc '
+                                    f'-t_srs EPSG:{tgt_epsg} '
+                                    f'-srcnodata 0 '
+                                    f'-r near '
+                                    f'-of ENVI '
+                                    f'-dstnodata none '
+                                    f'-et 0 '
+                                    f'-overwrite '
+                                    f'-te {" ".join([str(i) for i in tgt_extent])} '
+                                    f'{f"-tr {tgt_res[0]} {tgt_res[1]}" if tgt_res else ""}',
                                     v=True)
 
                 # get output X/Y size
@@ -260,7 +257,7 @@ class SensorMapGeometryTransformer(object):
             area_definition = AreaDefinition(area_id='',
                                              description='',
                                              proj_id='',
-                                             projection=get_proj4info(proj=tgt_prj),
+                                             projection=CRS(tgt_prj),
                                              width=x_size,
                                              height=y_size,
                                              area_extent=list(out_extent),
@@ -321,13 +318,7 @@ class SensorMapGeometryTransformer(object):
                                                                                    float, float, float], str):
         gt = area_definition.area_extent[0], area_definition.pixel_size_x, 0, \
              area_definition.area_extent[3], 0, -area_definition.pixel_size_y
-        with warnings.catch_warnings():
-            # suppress a UserWarning coming from pyresample v0.15.0
-            warnings.filterwarnings('ignore', category=UserWarning,
-                                    message='You will likely lose important projection information when converting '
-                                            'to a PROJ string from another format.')
-            proj4_str = area_definition.proj_str
-        prj = proj4_to_WKT(proj4_str)
+        prj = area_definition.crs.to_wkt()
 
         return gt, prj
 
@@ -366,7 +357,7 @@ class SensorMapGeometryTransformer(object):
             if not tgt_prj:
                 raise ValueError(tgt_prj, 'Target projection must be given if area_definition is not given.')
 
-            tgt_epsg = WKT2EPSG(proj4_to_WKT(get_proj4info(proj=tgt_prj)))
+            tgt_epsg = CRS(tgt_prj).to_epsg()
             tgt_extent = tgt_extent or self._get_target_extent(tgt_epsg)
 
             if tgt_coordgrid:
@@ -381,13 +372,12 @@ class SensorMapGeometryTransformer(object):
 
         # output validation
         if not data_mapgeo.shape[:2] == (self.area_definition.height, self.area_definition.width):
-            raise RuntimeError('The computed map geometry output does not have the expected number of rows/columns. '
-                               'Expected: %s; output: %s.'
-                               % (str((self.area_definition.height, self.area_definition.width)),
-                                  str(data_mapgeo.shape[:2])))
+            raise RuntimeError(f'The computed map geometry output does not have the expected number of rows/columns. '
+                               f'Expected: {str((self.area_definition.height, self.area_definition.width))}; '
+                               f'output: {str(data_mapgeo.shape[:2])}.')
         if data.ndim > 2 and data_mapgeo.ndim == 2:
-            raise RuntimeError('The computed map geometry output has only one band instead of the expected %d bands.'
-                               % data.shape[2])
+            raise RuntimeError(f'The computed map geometry output has only one band '
+                               f'instead of the expected {data.shape[2]} bands.')
 
         return data_mapgeo, out_gt, out_prj
 
@@ -400,10 +390,8 @@ class SensorMapGeometryTransformer(object):
         :param src_prj:     projection of the input map geometry array (WKT or 'epsg:1234' or <EPSG_int>)
         :param src_extent:  extent coordinates of input map geometry array (LL_x, LL_y, UR_x, UR_y) in the src_prj
         """
-        proj4_args = proj4_to_dict(get_proj4info(proj=src_prj))
-
         # get area_definition
-        self.area_definition = AreaDefinition('', '', '', proj4_args, data.shape[1], data.shape[0],
+        self.area_definition = AreaDefinition('', '', '',  CRS(src_prj), data.shape[1], data.shape[0],
                                               list(src_extent))
 
         # resample
@@ -411,19 +399,19 @@ class SensorMapGeometryTransformer(object):
 
         # output validation
         if not data_sensorgeo.shape[:2] == self.lats.shape[:2]:
-            raise RuntimeError('The computed sensor geometry output does not have the same X/Y dimension like the '
-                               'coordinates array. Coordinates array: %s; output array: %s.'
-                               % (self.lats.shape, data_sensorgeo.shape))
+            raise RuntimeError(f'The computed sensor geometry output does not have '
+                               f'the same X/Y dimension like the coordinates array. '
+                               f'Coordinates array: {self.lats.shape}; output array: {data_sensorgeo.shape}.')
 
         if data.ndim > 2 and data_sensorgeo.ndim == 2:
-            raise RuntimeError('The computed sensor geometry output has only one band instead of the expected %d bands.'
-                               % data.shape[2])
+            raise RuntimeError(f'The computed sensor geometry output has only one band '
+                               f'instead of the expected {data.shape[2]} bands.')
 
         return data_sensorgeo
 
 
 def _corner_coords_lonlat_to_extent(corner_coords_ll: List, tgt_epsg: int):
-    corner_coords_tgt_prj = [transform_any_prj(EPSG2WKT(4326), EPSG2WKT(tgt_epsg), x, y)
+    corner_coords_tgt_prj = [transform_any_prj(4326, tgt_epsg, x, y)
                              for x, y in corner_coords_ll]
     corner_coords_tgt_prj_np = np.array(corner_coords_tgt_prj)
     x_coords = corner_coords_tgt_prj_np[:, 0]
