@@ -26,10 +26,14 @@
 
 from typing import Union, Tuple
 import multiprocessing
+from concurrent.futures import TimeoutError as Timeout
+from warnings import warn
+import platform
 
+from pebble import ProcessPool, ProcessExpired
 import numpy as np
-from py_tools_ds.geo.projection import WKT2EPSG, EPSG2WKT, proj4_to_WKT
-from py_tools_ds.geo.coord_trafo import get_proj4info, transform_any_prj
+from pyproj import CRS
+from py_tools_ds.geo.coord_trafo import transform_any_prj
 
 from .transformer_2d import \
     SensorMapGeometryTransformer, _corner_coords_lonlat_to_extent, \
@@ -128,7 +132,7 @@ class SensorMapGeometryTransformer3D(object):
             UL_UR_LL_LR_ll = [(self.lons[y, x], self.lats[y, x]) for y, x in [(0, 0), (0, -1), (-1, 0), (-1, -1)]]
 
             # transform them to target projection
-            UL_UR_LL_LR_prj = [transform_any_prj(EPSG2WKT(4326), EPSG2WKT(tgt_epsg), x, y) for x, y in UL_UR_LL_LR_ll]
+            UL_UR_LL_LR_prj = [transform_any_prj(4326, tgt_epsg, x, y) for x, y in UL_UR_LL_LR_ll]
 
             # separate X and Y
             X_prj, Y_prj = zip(*UL_UR_LL_LR_prj)
@@ -154,7 +158,7 @@ class SensorMapGeometryTransformer3D(object):
                                     tgt_coordgrid: Tuple[Tuple, Tuple] = None
                                     ) -> AreaDefinition:
         # get common target extent
-        tgt_epsg = WKT2EPSG(proj4_to_WKT(get_proj4info(proj=tgt_prj)))
+        tgt_epsg = CRS(tgt_prj).to_epsg()
         tgt_extent = tgt_extent or self._get_common_target_extent(tgt_epsg, tgt_coordgrid=tgt_coordgrid)
 
         SMGT2D = SensorMapGeometryTransformer(lons=self.lons[:, :, 0],  # does NOT affect the computed area definition
@@ -221,11 +225,31 @@ class SensorMapGeometryTransformer3D(object):
         ) for band in range(data.shape[2])]
 
         if self.opts['nprocs'] > 1 and self.mp_alg == 'bands':
-            # NOTE: We use imap here as it directly returns the results when available (works like a generator).
+            # NOTE: The pebble ProcessPool directly returns the results when available (works like a generator).
             #       This saves a lot of memory compared with map. We also don't use an initializer to share the input
             #       arrays because this would allocate the memory for the input arrays of all bands at once.
-            with multiprocessing.Pool(self.opts['nprocs']) as pool:
-                result = [res for res in pool.imap_unordered(self._to_map_geometry_2D, args)]
+            # NOTE: Use a multiprocessing imap iterator here when the OpenMP is finally fixed in the pyresample side:
+            #       with multiprocessing.Pool(self.opts['nprocs']) as pool:
+            #           return [res for res in pool.imap_unordered(self._to_map_geometry_2D, args)]
+            try:
+                # this may cause a deadlock with the GNU OpenMP build, thus each WORKER has a timeout of 10 seconds
+                with ProcessPool() as pool:
+                    future = pool.map(self._to_map_geometry_2D, args, timeout=10)
+                    result = [i for i in future.result()]
+
+            except (Timeout, ProcessExpired):
+                # use mp_alg='tiles' instead which uses OpenMP under the hood
+                msg = "Switched multiprocessing algorithm from 'bands' to 'tiles' due to a timeout in 'bands' mode. "
+                if platform.system() == 'Linux':
+                    msg += "Consider using the LLVM instead of the GNU build of OpenMP to fix this issue (install, " \
+                           "e.g., by 'conda install -c conda-forge _openmp_mutex=*=1_llvm'."
+                warn(msg, RuntimeWarning)
+
+                init_opts = self.opts.copy()
+                for argset in args:
+                    argset.update(dict(init_opts=init_opts))
+
+                result = [self._to_map_geometry_2D(argsdict) for argsdict in args]
 
         else:
             result = [self._to_map_geometry_2D(argsdict) for argsdict in args]
